# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This is an auto-generated module.
It contains supporting classes for Filter and External Method.

"""

from . import ucscgenutils
from . import ucsccoreutils as coreutils
from .ucscmethod import ExternalMethod
from .ucsccoremeta import WriteXmlOption
from .ucscconstants import YesOrNo


def aaa_change_self_password(cookie, in_confirm_new_password, in_new_password, in_old_password, in_user_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaChangeSelfPassword")

    method.cookie = cookie
    method.in_confirm_new_password = in_confirm_new_password
    method.in_new_password = in_new_password
    method.in_old_password = in_old_password
    method.in_user_name = in_user_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_check_compute_auth_token(cookie, in_token, in_user):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaCheckComputeAuthToken")

    method.cookie = cookie
    method.in_token = in_token
    method.in_user = in_user

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_check_compute_ext_access(cookie, in_dn, in_user):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaCheckComputeExtAccess")

    method.cookie = cookie
    method.in_dn = in_dn
    method.in_user = in_user

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_get_auth_token_client(in_cookie):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaGetAuthTokenClient")

    method.in_cookie = in_cookie

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_get_auth_token_internal(cookie, in_id, in_ipv4, in_locales, in_parent_sess, in_priv, in_remote, in_role_list, in_user):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaGetAuthTokenInternal")

    method.cookie = cookie
    method.in_id = str(in_id)
    method.in_ipv4 = in_ipv4
    method.in_locales = in_locales
    method.in_parent_sess = in_parent_sess
    method.in_priv = in_priv
    method.in_remote = in_remote
    method.in_role_list = in_role_list
    method.in_user = in_user

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_get_compute_auth_token(cookie):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaGetComputeAuthToken")

    method.cookie = cookie

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_get_kvm_launch_url_internal(cookie, in_cimc_ipv4, in_ipv4, in_ipv6, in_locales, in_parent_sess, in_priv, in_remote, in_role_list, in_user):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaGetKVMLaunchUrlInternal")

    method.cookie = cookie
    method.in_cimc_ipv4 = in_cimc_ipv4
    method.in_ipv4 = in_ipv4
    method.in_ipv6 = in_ipv6
    method.in_locales = in_locales
    method.in_parent_sess = in_parent_sess
    method.in_priv = in_priv
    method.in_remote = in_remote
    method.in_role_list = in_role_list
    method.in_user = in_user

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_get_n_compute_auth_token_by_dn(cookie, in_cookie, in_dn, in_number_of):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaGetNComputeAuthTokenByDn")

    method.cookie = cookie
    method.in_dn = in_dn
    method.in_number_of = str(in_number_of)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_get_n_compute_auth_token_internal_by_dn(cookie, in_dn, in_id, in_ipv4, in_locales, in_number_of, in_parent_sess, in_priv, in_remote, in_role_list, in_user):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaGetNComputeAuthTokenInternalByDn")

    method.cookie = cookie
    method.in_dn = in_dn
    method.in_id = str(in_id)
    method.in_ipv4 = in_ipv4
    method.in_locales = in_locales
    method.in_number_of = str(in_number_of)
    method.in_parent_sess = in_parent_sess
    method.in_priv = in_priv
    method.in_remote = in_remote
    method.in_role_list = in_role_list
    method.in_user = in_user

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_get_remote_user_roles(cookie, in_remote_user_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaGetRemoteUserRoles")

    method.cookie = cookie
    method.in_remote_user_name = in_remote_user_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_get_user_locales(cookie, in_is_user_remote, in_user_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaGetUserLocales")

    method.cookie = cookie
    method.in_is_user_remote = in_is_user_remote
    method.in_user_name = in_user_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_keep_alive(cookie):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaKeepAlive")

    method.cookie = cookie

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_login(in_name, in_password):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaLogin")

    method.in_name = in_name
    method.in_password = in_password

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_login_by_token(cookie, in_name, in_token):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaLoginByToken")

    method.cookie = cookie
    method.in_name = in_name
    method.in_token = in_token

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_logout(in_cookie):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaLogout")

    method.in_cookie = in_cookie

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_refresh(in_cookie, in_name, in_password):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaRefresh")

    method.in_cookie = in_cookie
    method.in_name = in_name
    method.in_password = in_password

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_token_login(cookie, in_name, in_token):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaTokenLogin")

    method.cookie = cookie
    method.in_name = in_name
    method.in_token = in_token

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def aaa_token_refresh(in_cookie, in_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("AaaTokenRefresh")

    method.in_cookie = in_cookie
    method.in_name = in_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def cliview_conf_mos(cookie, in_additional_methods, in_commit, in_configs, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("CliviewConfMos")

    method.cookie = cookie
    method.in_additional_methods = in_additional_methods
    method.in_commit = in_commit
    method.in_configs = in_configs
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def compute_get_qualified_servers(cookie, in_qual_dn, in_return_pool_configs, in_return_server_configs):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ComputeGetQualifiedServers")

    method.cookie = cookie
    method.in_qual_dn = in_qual_dn
    method.in_return_pool_configs = in_return_pool_configs
    method.in_return_server_configs = in_return_server_configs

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def compute_get_server_catalog(cookie, in_domain_group_list, in_equipment_filter, in_exclude_total_result_size, in_filter, in_include_filter_list_only, in_include_props, in_limit, in_offset, in_recursive, in_return_count_only):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ComputeGetServerCatalog")

    method.cookie = cookie
    method.in_domain_group_list = in_domain_group_list
    method.in_equipment_filter = in_equipment_filter
    method.in_exclude_total_result_size = in_exclude_total_result_size
    method.in_filter = in_filter
    method.in_include_filter_list_only = in_include_filter_list_only
    method.in_include_props = in_include_props
    method.in_limit = str(in_limit)
    method.in_offset = str(in_offset)
    method.in_recursive = in_recursive
    method.in_return_count_only = in_return_count_only

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def compute_re_qualify_membership(cookie, dn):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ComputeReQualifyMembership")

    method.cookie = cookie
    method.dn = dn

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_check_hardware_compatibility(cookie, class_id, in_target_blade_firmware_version, in_target_dn, in_target_modular_firmware_version, in_target_rack_firmware_version, in_target_ucs_firmware_version):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigCheckHardwareCompatibility")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_target_blade_firmware_version = in_target_blade_firmware_version
    method.in_target_dn = in_target_dn
    method.in_target_modular_firmware_version = in_target_modular_firmware_version
    method.in_target_rack_firmware_version = in_target_rack_firmware_version
    method.in_target_ucs_firmware_version = in_target_ucs_firmware_version

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_clone(cookie, dn, in_chassis_profile_name, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigClone")

    method.cookie = cookie
    method.dn = dn
    method.in_chassis_profile_name = in_chassis_profile_name
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_conf_filtered(cookie, class_id, in_config, in_filter, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigConfFiltered")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_config = in_config
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_conf_mo(cookie, dn, in_config, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigConfMo")

    method.cookie = cookie
    method.dn = dn
    method.in_config = in_config
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_conf_mo_group(cookie, in_config, in_dns, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigConfMoGroup")

    method.cookie = cookie
    method.in_config = in_config
    method.in_dns = in_dns
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_conf_mos(cookie, in_configs, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigConfMos")

    method.cookie = cookie
    method.in_configs = in_configs
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_conf_rename(cookie, dn, in_new_name, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigConfRename")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_new_name = in_new_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_delete_mo(cookie, dn, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigDeleteMo")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_find_dependencies(cookie, dn, in_return_configs):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigFindDependencies")

    method.cookie = cookie
    method.dn = dn
    method.in_return_configs = in_return_configs

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_find_dns_by_class_id(cookie, class_id, in_filter):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigFindDnsByClassId")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_filter = in_filter

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_find_policy_usage(cookie, in_policy_dn, in_policy_usage, in_return_configs):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigFindPolicyUsage")

    method.cookie = cookie
    method.in_policy_dn = in_policy_dn
    method.in_policy_usage = in_policy_usage
    method.in_return_configs = in_return_configs

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_ackables(cookie):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetAckables")

    method.cookie = cookie

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_connected_endpoints(cookie, in_equipment_dn, in_equpiment_id_filter):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetConnectedEndpoints")

    method.cookie = cookie
    method.in_equipment_dn = in_equipment_dn
    method.in_equpiment_id_filter = in_equpiment_id_filter

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_estimate_impact(cookie, in_configs, in_deleted_dns, in_impact_analyzer_id, in_is_policy_full_config, in_source_connector_id):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetEstimateImpact")

    method.cookie = cookie
    method.in_configs = in_configs
    method.in_deleted_dns = in_deleted_dns
    method.in_impact_analyzer_id = in_impact_analyzer_id
    method.in_is_policy_full_config = in_is_policy_full_config
    method.in_source_connector_id = str(in_source_connector_id)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_id_universe_usage(cookie, in_domain_group_dn, in_id_type, in_show_id_details):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetIdUniverseUsage")

    method.cookie = cookie
    method.in_domain_group_dn = in_domain_group_dn
    method.in_id_type = in_id_type
    method.in_show_id_details = in_show_id_details

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_last_backed_up_domains(cookie, in_backup_type, in_domains):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetLastBackedUpDomains")

    method.cookie = cookie
    method.in_backup_type = in_backup_type
    method.in_domains = in_domains

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_net_refs(cookie, in_org_dn, in_server_dn, in_type):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetNetRefs")

    method.cookie = cookie
    method.in_org_dn = in_org_dn
    method.in_server_dn = in_server_dn
    method.in_type = in_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_policy_domain_group(cookie, in_class_id, in_domain_id, in_policy_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetPolicyDomainGroup")

    method.cookie = cookie
    method.in_class_id = str(in_class_id)
    method.in_domain_id = str(in_domain_id)
    method.in_policy_name = in_policy_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_qualified_domains(cookie, in_qual_dn, in_return_domain_configs, in_return_policy_configs):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetQualifiedDomains")

    method.cookie = cookie
    method.in_qual_dn = in_qual_dn
    method.in_return_domain_configs = in_return_domain_configs
    method.in_return_policy_configs = in_return_policy_configs

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_get_token_requestors(cookie):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigGetTokenRequestors")

    method.cookie = cookie

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_instantiate_n_named_template(cookie, dn, in_error_on_existing, in_name_set, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigInstantiateNNamedTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_error_on_existing = in_error_on_existing
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_name_set = in_name_set
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_instantiate_n_template(cookie, dn, in_chassis_profile_name_prefix_or_empty, in_number_of, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigInstantiateNTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_chassis_profile_name_prefix_or_empty = in_chassis_profile_name_prefix_or_empty
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_number_of = str(in_number_of)
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_instantiate_template(cookie, dn, in_chassis_profile_name, in_error_on_existing, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigInstantiateTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_chassis_profile_name = in_chassis_profile_name
    method.in_error_on_existing = in_error_on_existing
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_mo_change_event(cookie, in_config, in_eid):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigMoChangeEvent")

    method.cookie = cookie
    method.in_config = in_config
    method.in_eid = str(in_eid)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_publish_vlan(cookie, in_domain, in_vlan_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigPublishVlan")

    method.cookie = cookie
    method.in_domain = in_domain
    method.in_vlan_name = in_vlan_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_publish_vsan(cookie, in_domain, in_switch_id, in_vsan_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigPublishVsan")

    method.cookie = cookie
    method.in_domain = in_domain
    method.in_switch_id = in_switch_id
    method.in_vsan_name = in_vsan_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_refresh_identity(cookie, dn, in_id_type, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigRefreshIdentity")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_id_type = in_id_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_release_resolve_context(cookie, in_context):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigReleaseResolveContext")

    method.cookie = cookie
    method.in_context = str(in_context)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_remote_search(cookie, in_context, in_domain_id, in_domain_name, in_fetch_size, in_name, in_object_type, in_policy_owner, in_recursive_context, in_recursive_domain_group, in_search_domain_group, in_search_type):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigRemoteSearch")

    method.cookie = cookie
    method.in_context = in_context
    method.in_domain_id = str(in_domain_id)
    method.in_domain_name = in_domain_name
    method.in_fetch_size = str(in_fetch_size)
    method.in_name = in_name
    method.in_object_type = in_object_type
    method.in_policy_owner = in_policy_owner
    method.in_recursive_context = in_recursive_context
    method.in_recursive_domain_group = in_recursive_domain_group
    method.in_search_domain_group = in_search_domain_group
    method.in_search_type = in_search_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_renew_resolve_context(cookie, in_context):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigRenewResolveContext")

    method.cookie = cookie
    method.in_context = str(in_context)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_ancestor(cookie, dn, in_class, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveAncestor")

    method.cookie = cookie
    method.dn = dn
    method.in_class = in_class
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_children(cookie, class_id, in_dn, in_filter, in_include_props=None, in_return_count_only=None, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveChildren")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_dn = in_dn
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    if in_include_props is not None:
        method.in_include_props = in_include_props
    if in_return_count_only is not None:
        method.in_return_count_only = in_return_count_only

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_children_sorted(cookie, class_id, in_dn, in_filter, in_size, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveChildrenSorted")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_dn = in_dn
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_size = str(in_size)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_class(cookie, class_id, in_filter, in_include_props=None, in_return_count_only=None, in_limit=0, in_offset=0, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveClass")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    if in_include_props is not None:
        method.in_include_props = in_include_props
    if in_limit > 0:
        method.in_limit = in_limit
    if in_offset > 0:
        method.in_offset = in_offset
    if in_return_count_only is not None:
        method.in_return_count_only = in_return_count_only

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_class_db(cookie, class_id, in_filter, in_include_prop, in_key, in_limit, in_offset, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveClassDB")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_include_prop = in_include_prop
    method.in_key = in_key
    method.in_limit = str(in_limit)
    method.in_offset = str(in_offset)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_class_filter_idx(cookie, class_id, in_class, in_filter, in_include_prop, in_limit, in_offset, in_parent_dn, in_query, in_sort_str, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveClassFilterIdx")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_class = in_class
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_include_prop = in_include_prop
    method.in_limit = str(in_limit)
    method.in_offset = str(in_offset)
    method.in_parent_dn = in_parent_dn
    method.in_query = in_query
    method.in_sort_str = in_sort_str

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_class_idx(cookie, class_id, in_class, in_filter, in_include_prop, in_limit, in_offset, in_parent_dn, in_query, in_sort_str, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveClassIdx")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_class = in_class
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_include_prop = in_include_prop
    method.in_limit = str(in_limit)
    method.in_offset = str(in_offset)
    method.in_parent_dn = in_parent_dn
    method.in_query = in_query
    method.in_sort_str = in_sort_str

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_class_sorted(cookie, class_id, in_filter, in_size, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveClassSorted")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_size = str(in_size)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_classes(cookie, in_ids, in_return_count_only, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveClasses")

    method.cookie = cookie
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_ids = in_ids
    method.in_return_count_only = in_return_count_only

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_classes_sorted(cookie, in_ids, in_size, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveClassesSorted")

    method.cookie = cookie
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_ids = in_ids
    method.in_size = str(in_size)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_context(cookie, in_context, in_size):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveContext")

    method.cookie = cookie
    method.in_context = str(in_context)
    method.in_size = str(in_size)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_dn(cookie, dn, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveDn")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_dns(cookie, in_dns, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveDns")

    method.cookie = cookie
    method.in_dns = in_dns
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_domain_elements(cookie, in_assoc_state, in_class_id, in_domain_group_context, in_domain_id, in_fetch_size, in_filter, in_ignore_assoc_state, in_include_filter_list_only, in_include_props, in_instance_type, in_limit, in_name, in_offset, in_org_context, in_owner, in_recursive_domain_group, in_recursive_org_group, in_return_count_only):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveDomainElements")

    method.cookie = cookie
    method.in_assoc_state = in_assoc_state
    method.in_class_id = in_class_id
    method.in_domain_group_context = in_domain_group_context
    method.in_domain_id = str(in_domain_id)
    method.in_fetch_size = str(in_fetch_size)
    method.in_filter = in_filter
    method.in_ignore_assoc_state = in_ignore_assoc_state
    method.in_include_filter_list_only = in_include_filter_list_only
    method.in_include_props = in_include_props
    method.in_instance_type = in_instance_type
    method.in_limit = str(in_limit)
    method.in_name = in_name
    method.in_offset = str(in_offset)
    method.in_org_context = in_org_context
    method.in_owner = in_owner
    method.in_recursive_domain_group = in_recursive_domain_group
    method.in_recursive_org_group = in_recursive_org_group
    method.in_return_count_only = in_return_count_only

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_parent(cookie, dn, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveParent")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_resolve_spot_light_idx(cookie, class_id, in_class, in_filter, in_include_facet, in_include_prop, in_limit, in_offset, in_query, in_sort_str):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigResolveSpotLightIdx")

    meta_class_id = coreutils.find_class_id_in_mo_meta_ignore_case(class_id)
    if meta_class_id is not None:
        class_id = ucscgenutils.word_l(meta_class_id)
    method.class_id = class_id
    method.cookie = cookie
    method.in_class = in_class
    method.in_filter = in_filter
    method.in_include_facet = in_include_facet
    method.in_include_prop = in_include_prop
    method.in_limit = str(in_limit)
    method.in_offset = str(in_offset)
    method.in_query = in_query
    method.in_sort_str = in_sort_str

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_scope(cookie, dn, in_class, in_filter, in_recursive, in_return_count_only=None, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigScope")

    method.cookie = cookie
    method.dn = dn
    method.in_class = in_class
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_recursive = in_recursive
    if in_return_count_only is not None:
        method.in_return_count_only = in_return_count_only

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_send_app_impact_response(cookie, in_app_impact_response_set):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigSendAppImpactResponse")

    method.cookie = cookie
    method.in_app_impact_response_set = in_app_impact_response_set

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_tags(cookie, in_configs):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigTags")

    method.cookie = cookie
    method.in_configs = in_configs

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_templatise(cookie, dn, in_target_org, in_template_name, in_template_type, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigTemplatise")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_target_org = in_target_org
    method.in_template_name = in_template_name
    method.in_template_type = in_template_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def config_uc_estimate_impact(cookie, in_configs, in_impact_analyzer_id):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("ConfigUCEstimateImpact")

    method.cookie = cookie
    method.in_configs = in_configs
    method.in_impact_analyzer_id = str(in_impact_analyzer_id)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def equipment_clone(cookie, dn, in_chassis_profile_name, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("EquipmentClone")

    method.cookie = cookie
    method.dn = dn
    method.in_chassis_profile_name = in_chassis_profile_name
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def equipment_instantiate_n_named_template(cookie, dn, in_error_on_existing, in_name_set, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("EquipmentInstantiateNNamedTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_error_on_existing = in_error_on_existing
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_name_set = in_name_set
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def equipment_instantiate_n_template(cookie, dn, in_chassis_profile_name_prefix_or_empty, in_number_of, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("EquipmentInstantiateNTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_chassis_profile_name_prefix_or_empty = in_chassis_profile_name_prefix_or_empty
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_number_of = str(in_number_of)
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def equipment_instantiate_template(cookie, dn, in_chassis_profile_name, in_error_on_existing, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("EquipmentInstantiateTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_chassis_profile_name = in_chassis_profile_name
    method.in_error_on_existing = in_error_on_existing
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def equipment_templatise(cookie, dn, in_target_org, in_template_name, in_template_type, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("EquipmentTemplatise")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_target_org = in_target_org
    method.in_template_name = in_template_name
    method.in_template_type = in_template_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def event_send_heartbeat(cookie):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("EventSendHeartbeat")

    method.cookie = cookie

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def event_subscribe(cookie, in_filter):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("EventSubscribe")

    method.cookie = cookie
    method.in_filter = in_filter

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def event_subscribe_apps(cookie, in_app_list, in_filter):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("EventSubscribeApps")

    method.cookie = cookie
    method.in_app_list = in_app_list
    method.in_filter = in_filter

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fabric_permits_for_existing_vlan_names(cookie, in_org_dn):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FabricPermitsForExistingVlanNames")

    method.cookie = cookie
    method.in_org_dn = in_org_dn

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fabric_resolve_vlan_permits(cookie, in_action, in_domain_group_list, in_from, in_org_list, in_pub_nw_name, in_to, in_vlan_list, in_vlan_name, in_vlan_prefix, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FabricResolveVlanPermits")

    method.cookie = cookie
    method.in_action = in_action
    method.in_domain_group_list = in_domain_group_list
    method.in_from = str(in_from)
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_org_list = in_org_list
    method.in_pub_nw_name = in_pub_nw_name
    method.in_to = str(in_to)
    method.in_vlan_list = in_vlan_list
    method.in_vlan_name = in_vlan_name
    method.in_vlan_prefix = in_vlan_prefix

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fabric_vnet_id_ep_overlap_check(cookie, in_class_id, in_delimiter, in_id_type, in_ids_to_check, in_should_return_overlapping_vnets):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FabricVnetIdEpOverlapCheck")

    method.cookie = cookie
    method.in_class_id = in_class_id
    method.in_delimiter = in_delimiter
    method.in_id_type = in_id_type
    method.in_ids_to_check = in_ids_to_check
    method.in_should_return_overlapping_vnets = in_should_return_overlapping_vnets

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fault_ack_fault(cookie, in_id):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FaultAckFault")

    method.cookie = cookie
    method.in_id = str(in_id)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fault_ack_fault_by_dn(cookie, dn):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FaultAckFaultByDn")

    method.cookie = cookie
    method.dn = dn

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fault_ack_faults(cookie, in_ids):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FaultAckFaults")

    method.cookie = cookie
    method.in_ids = in_ids

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fault_ack_faults_by_dn(cookie, in_dns):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FaultAckFaultsByDn")

    method.cookie = cookie
    method.in_dns = in_dns

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fault_resolve_fault(cookie, in_id):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FaultResolveFault")

    method.cookie = cookie
    method.in_id = str(in_id)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def firmware_estimate_pack_impact(cookie, dn, in_group_dn, in_pack_configs):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FirmwareEstimatePackImpact")

    method.cookie = cookie
    method.dn = dn
    method.in_group_dn = in_group_dn
    method.in_pack_configs = in_pack_configs

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def firmware_install_all(cookie, dn, in_concurrent_jobs, in_group_dn, in_honor_ls_maint, in_ignore_comp_check, in_packages, in_start_time, in_user_ack):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FirmwareInstallAll")

    method.cookie = cookie
    method.dn = dn
    method.in_concurrent_jobs = str(in_concurrent_jobs)
    method.in_group_dn = in_group_dn
    method.in_honor_ls_maint = in_honor_ls_maint
    method.in_ignore_comp_check = in_ignore_comp_check
    method.in_packages = in_packages
    method.in_start_time = in_start_time
    method.in_user_ack = in_user_ack

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def fsm_debug_action(cookie, dn, in_directive):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("FsmDebugAction")

    method.cookie = cookie
    method.dn = dn
    method.in_directive = in_directive

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def ident_get_block_report(cookie, in_block, in_pool):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("IdentGetBlockReport")

    method.cookie = cookie
    method.in_block = in_block
    method.in_pool = in_pool

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def ident_get_id_usage(cookie, in_pool_dn):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("IdentGetIdUsage")

    method.cookie = cookie
    method.in_pool_dn = in_pool_dn

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def ident_get_sorted_ids(cookie, in_block, in_pool):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("IdentGetSortedIds")

    method.cookie = cookie
    method.in_block = in_block
    method.in_pool = in_pool

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def logging_sync_ocns(cookie, in_from_or_zero, in_to_or_zero):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("LoggingSyncOcns")

    method.cookie = cookie
    method.in_from_or_zero = str(in_from_or_zero)
    method.in_to_or_zero = str(in_to_or_zero)

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def ls_clone(cookie, dn, in_server_name, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("LsClone")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_server_name = in_server_name
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def ls_instantiate_n_named_template(cookie, dn, in_error_on_existing, in_name_set, in_pool_name, in_qualifier_name, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("LsInstantiateNNamedTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_error_on_existing = in_error_on_existing
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_name_set = in_name_set
    method.in_pool_name = in_pool_name
    method.in_qualifier_name = in_qualifier_name
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def ls_instantiate_n_template(cookie, dn, in_number_of, in_pool_name, in_qualifier_name, in_server_name_prefix_or_empty, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("LsInstantiateNTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_number_of = str(in_number_of)
    method.in_pool_name = in_pool_name
    method.in_qualifier_name = in_qualifier_name
    method.in_server_name_prefix_or_empty = in_server_name_prefix_or_empty
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def ls_instantiate_template(cookie, dn, in_error_on_existing, in_server_name, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("LsInstantiateTemplate")

    method.cookie = cookie
    method.dn = dn
    method.in_error_on_existing = in_error_on_existing
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_server_name = in_server_name
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def ls_templatise(cookie, dn, in_target_org, in_template_name, in_template_type, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("LsTemplatise")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_target_org = in_target_org
    method.in_template_name = in_template_name
    method.in_template_type = in_template_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def lstorage_clone(cookie, dn, in_array_name, in_target_org, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("LstorageClone")

    method.cookie = cookie
    method.dn = dn
    method.in_array_name = in_array_name
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_target_org = in_target_org

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def method_vessel(cookie, in_stimuli):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("MethodVessel")

    method.cookie = cookie
    method.in_stimuli = in_stimuli

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def org_get_domain_firmware_report(cookie, in_domain_group_dn, in_domain_list, in_firmware_type, in_maint_tag):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("OrgGetDomainFirmwareReport")

    method.cookie = cookie
    method.in_domain_group_dn = in_domain_group_dn
    method.in_domain_list = in_domain_list
    method.in_firmware_type = in_firmware_type
    method.in_maint_tag = in_maint_tag

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def org_get_domain_policy_report(cookie, in_config, in_domain_group_dn, in_domain_type):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("OrgGetDomainPolicyReport")

    method.cookie = cookie
    method.in_config = in_config
    method.in_domain_group_dn = in_domain_group_dn
    method.in_domain_type = in_domain_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def org_get_impacted_domains(cookie, in_config, in_domain_group_dn, in_domain_type, in_dynamic, in_firmware_type, in_maint_tag, in_profile_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("OrgGetImpactedDomains")

    method.cookie = cookie
    method.in_config = in_config
    method.in_domain_group_dn = in_domain_group_dn
    method.in_domain_type = in_domain_type
    method.in_dynamic = in_dynamic
    method.in_firmware_type = in_firmware_type
    method.in_maint_tag = in_maint_tag
    method.in_profile_name = in_profile_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def org_get_num_impacted_domains(cookie, in_config, in_domain_group_dn, in_dynamic, in_firmware_type, in_maint_tag, in_profile_name):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("OrgGetNumImpactedDomains")

    method.cookie = cookie
    method.in_config = in_config
    method.in_domain_group_dn = in_domain_group_dn
    method.in_dynamic = in_dynamic
    method.in_firmware_type = in_firmware_type
    method.in_maint_tag = in_maint_tag
    method.in_profile_name = in_profile_name

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def org_get_subscribed_domains(cookie, in_class_id, in_domain_group_dn, in_subscription_type):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("OrgGetSubscribedDomains")

    method.cookie = cookie
    method.in_class_id = str(in_class_id)
    method.in_domain_group_dn = in_domain_group_dn
    method.in_subscription_type = in_subscription_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def org_resolve_elements(cookie, dn, in_class, in_filter, in_single_level, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("OrgResolveElements")

    method.cookie = cookie
    method.dn = dn
    method.in_class = in_class
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_single_level = in_single_level

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def org_resolve_in_scope(cookie, dn, in_class, in_filter, in_single_level, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("OrgResolveInScope")

    method.cookie = cookie
    method.dn = dn
    method.in_class = in_class
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_single_level = in_single_level

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def org_resolve_logical_parents(cookie, dn, in_single_level, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("OrgResolveLogicalParents")

    method.cookie = cookie
    method.dn = dn
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_single_level = in_single_level

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def policy_resolve_names(cookie, in_client_connector_dn, in_context, in_filter, in_policy_type):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("PolicyResolveNames")

    method.cookie = cookie
    method.in_client_connector_dn = in_client_connector_dn
    method.in_context = in_context
    method.in_filter = in_filter
    method.in_policy_type = in_policy_type

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def pool_resolve_in_scope(cookie, dn, in_class, in_filter, in_single_level, in_hierarchical=YesOrNo.FALSE):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("PoolResolveInScope")

    method.cookie = cookie
    method.dn = dn
    method.in_class = in_class
    method.in_filter = in_filter
    method.in_hierarchical = (("false", "true")[in_hierarchical in ucscgenutils.AFFIRMATIVE_LIST])
    method.in_single_level = in_single_level

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def snmp_find_var(cookie, in_is_exact, in_oid):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("SnmpFindVar")

    method.cookie = cookie
    method.in_is_exact = in_is_exact
    method.in_oid = in_oid

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def stats_build_chart_result(cookie, dn):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("StatsBuildChartResult")

    method.cookie = cookie
    method.dn = dn

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def stats_build_custom_chart(cookie, in_aggregate_by_dn, in_end_time, in_overlay, in_resolve_dns, in_start_time, in_stats_types):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("StatsBuildCustomChart")

    method.cookie = cookie
    method.in_aggregate_by_dn = in_aggregate_by_dn
    method.in_end_time = str(in_end_time)
    method.in_overlay = in_overlay
    method.in_resolve_dns = in_resolve_dns
    method.in_start_time = str(in_start_time)
    method.in_stats_types = in_stats_types

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def stats_build_standard_chart(cookie, in_aggregation_property, in_context_class, in_count, in_end_time, in_overlay, in_parent_dn, in_report_type, in_start_time, in_stats_types):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("StatsBuildStandardChart")

    method.cookie = cookie
    method.in_aggregation_property = in_aggregation_property
    method.in_context_class = in_context_class
    method.in_count = str(in_count)
    method.in_end_time = str(in_end_time)
    method.in_overlay = in_overlay
    method.in_parent_dn = in_parent_dn
    method.in_report_type = in_report_type
    method.in_start_time = str(in_start_time)
    method.in_stats_types = in_stats_types

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def stats_clear_interval(cookie, in_dns):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("StatsClearInterval")

    method.cookie = cookie
    method.in_dns = in_dns

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def stats_subscribe(cookie, in_category, in_provider, in_schema_info, in_time_interval):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("StatsSubscribe")

    method.cookie = cookie
    method.in_category = in_category
    method.in_provider = in_provider
    method.in_schema_info = in_schema_info
    method.in_time_interval = in_time_interval

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def synthetic_fs_obj_inventory(cookie, dn, in_config):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("SyntheticFSObjInventory")

    method.cookie = cookie
    method.dn = dn
    method.in_config = in_config

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def synthetic_fs_obj_inventory_b(cookie, in_config):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("SyntheticFSObjInventoryB")

    method.cookie = cookie
    method.in_config = in_config

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request


def synthetic_test_tx(cookie, in_config, in_test, in_what):
    """ Auto-generated UCSC XML API Method. """
    method = ExternalMethod("SyntheticTestTx")

    method.cookie = cookie
    method.in_config = in_config
    method.in_test = in_test
    method.in_what = in_what

    xml_request = method.to_xml(option=WriteXmlOption.DIRTY)
    return xml_request




"""This module contains the general information for LsbootEFIShell ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class LsbootEFIShellConsts():
    ACCESS_READ_ONLY = "read-only"
    ACCESS_READ_ONLY_LOCAL = "read-only-local"
    ACCESS_READ_ONLY_REMOTE = "read-only-remote"
    ACCESS_READ_ONLY_REMOTE_CIMC = "read-only-remote-cimc"
    ACCESS_READ_WRITE = "read-write"
    ACCESS_READ_WRITE_DRIVE = "read-write-drive"
    ACCESS_READ_WRITE_LOCAL = "read-write-local"
    ACCESS_READ_WRITE_REMOTE = "read-write-remote"
    ACCESS_READ_WRITE_REMOTE_CIMC = "read-write-remote-cimc"
    TYPE_EFI_SHELL = "efi-shell"
    TYPE_ISCSI = "iscsi"
    TYPE_LAN = "lan"
    TYPE_SAN = "san"
    TYPE_STORAGE = "storage"
    TYPE_VIRTUAL_MEDIA = "virtual-media"


class LsbootEFIShell(ManagedObject):
    """This is LsbootEFIShell class."""

    consts = LsbootEFIShellConsts()
    naming_props = set([])

    mo_meta = MoMeta("LsbootEFIShell", "lsbootEFIShell", "efi-shell", VersionMeta.Version151a, "InputOutput", 0x1f, [], ["admin", "ls-compute", "ls-config", "ls-config-policy", "ls-server", "ls-server-policy", "ls-storage", "ls-storage-policy"], [u'lsbootDef', u'lsbootPolicy'], [], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "access": MoPropertyMeta("access", "access", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["read-only", "read-only-local", "read-only-remote", "read-only-remote-cimc", "read-write", "read-write-drive", "read-write-local", "read-write-remote", "read-write-remote-cimc"], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "order": MoPropertyMeta("order", "order", "ushort", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, [], ["1-16"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["efi-shell", "iscsi", "lan", "san", "storage", "virtual-media"], []), 
    }

    prop_map = {
        "access": "access", 
        "childAction": "child_action", 
        "dn": "dn", 
        "order": "order", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.access = None
        self.child_action = None
        self.order = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "LsbootEFIShell", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ConfigManagedEpImpactResponse ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ConfigManagedEpImpactResponseConsts():
    PROFILE_TYPE_CHASSIS_PROFILE = "chassis-profile"
    PROFILE_TYPE_SERVICE_PROFILE = "service-profile"
    REBOOT_REQUIRED_FALSE = "false"
    REBOOT_REQUIRED_NO = "no"
    REBOOT_REQUIRED_TRUE = "true"
    REBOOT_REQUIRED_YES = "yes"
    STATE_COMPLETE = "complete"
    STATE_LOST_VISIBILITY = "lost-visibility"
    STATE_NOT_STARTED = "not-started"
    STATE_SUSPEND = "suspend"
    STATE_TIMED_OUT = "timed-out"
    STATE_WAITING = "waiting"


class ConfigManagedEpImpactResponse(ManagedObject):
    """This is ConfigManagedEpImpactResponse class."""

    consts = ConfigManagedEpImpactResponseConsts()
    naming_props = set([u'appConnectorId', u'sourceConnectorId'])

    mo_meta = MoMeta("ConfigManagedEpImpactResponse", "configManagedEpImpactResponse", "ManagedEpapp-id-[app_connector_id]src-id-[source_connector_id]", VersionMeta.Version111a, "InputOutput", 0x1ff, [], ["read-only"], [u'configImpactAnalyzer'], [u'configImpact'], [None])

    prop_meta = {
        "affected_chassis_cnt": MoPropertyMeta("affected_chassis_cnt", "affectedChassisCnt", "ushort", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "affected_servers": MoPropertyMeta("affected_servers", "affectedServers", "ushort", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "app_connector_id": MoPropertyMeta("app_connector_id", "appConnectorId", "uint", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x2, None, None, None, [], []), 
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "ep_name": MoPropertyMeta("ep_name", "epName", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[\-\.:_a-zA-Z0-9]{0,16}""", [], []), 
        "impact_analyzer_id": MoPropertyMeta("impact_analyzer_id", "impactAnalyzerId", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "profile_type": MoPropertyMeta("profile_type", "profileType", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["chassis-profile", "service-profile"], []), 
        "reboot_required": MoPropertyMeta("reboot_required", "rebootRequired", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x20, 0, 256, None, [], []), 
        "source_connector_id": MoPropertyMeta("source_connector_id", "sourceConnectorId", "uint", VersionMeta.Version111a, MoPropertyMeta.NAMING, 0x40, None, None, None, [], []), 
        "state": MoPropertyMeta("state", "state", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["complete", "lost-visibility", "not-started", "suspend", "timed-out", "waiting"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "affectedChassisCnt": "affected_chassis_cnt", 
        "affectedServers": "affected_servers", 
        "appConnectorId": "app_connector_id", 
        "childAction": "child_action", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "epName": "ep_name", 
        "impactAnalyzerId": "impact_analyzer_id", 
        "profileType": "profile_type", 
        "rebootRequired": "reboot_required", 
        "rn": "rn", 
        "sourceConnectorId": "source_connector_id", 
        "state": "state", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, app_connector_id, source_connector_id, **kwargs):
        self._dirty_mask = 0
        self.app_connector_id = app_connector_id
        self.source_connector_id = source_connector_id
        self.affected_chassis_cnt = None
        self.affected_servers = None
        self.child_action = None
        self.ep_dn = None
        self.ep_name = None
        self.impact_analyzer_id = None
        self.profile_type = None
        self.reboot_required = None
        self.state = None
        self.status = None

        ManagedObject.__init__(self, "ConfigManagedEpImpactResponse", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StatsCollectionPolicy ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StatsCollectionPolicyConsts():
    COLLECTION_INTERVAL_1MINUTE = "1minute"
    COLLECTION_INTERVAL_2MINUTES = "2minutes"
    COLLECTION_INTERVAL_30SECONDS = "30seconds"
    COLLECTION_INTERVAL_5MINUTES = "5minutes"
    NAME_ADAPTER = "adapter"
    NAME_CHASSIS = "chassis"
    NAME_FEX = "fex"
    NAME_HOST = "host"
    NAME_PORT = "port"
    NAME_SERVER = "server"
    NAME_UNKNOWN = "unknown"
    REPORTING_INTERVAL_15MINUTES = "15minutes"
    REPORTING_INTERVAL_2HOURS = "2hours"
    REPORTING_INTERVAL_2MINUTES = "2minutes"
    REPORTING_INTERVAL_30MINUTES = "30minutes"
    REPORTING_INTERVAL_4HOURS = "4hours"
    REPORTING_INTERVAL_60MINUTES = "60minutes"
    REPORTING_INTERVAL_8HOURS = "8hours"


class StatsCollectionPolicy(ManagedObject):
    """This is StatsCollectionPolicy class."""

    consts = StatsCollectionPolicyConsts()
    naming_props = set([u'name'])

    mo_meta = MoMeta("StatsCollectionPolicy", "statsCollectionPolicy", "coll-policy-[name]", VersionMeta.Version101a, "InputOutput", 0xff, [], ["admin", "operations"], [u'statsHolder'], [], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "collection_interval": MoPropertyMeta("collection_interval", "collectionInterval", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["1minute", "2minutes", "30seconds", "5minutes"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "ushort", VersionMeta.Version101a, MoPropertyMeta.CREATE_ONLY, 0x8, None, None, None, [], []), 
        "name": MoPropertyMeta("name", "name", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x10, None, None, None, ["adapter", "chassis", "fex", "host", "port", "server", "unknown"], []), 
        "reporting_interval": MoPropertyMeta("reporting_interval", "reportingInterval", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["15minutes", "2hours", "2minutes", "30minutes", "4hours", "60minutes", "8hours"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x80, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "collectionInterval": "collection_interval", 
        "dn": "dn", 
        "id": "id", 
        "name": "name", 
        "reportingInterval": "reporting_interval", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, name, **kwargs):
        self._dirty_mask = 0
        self.name = name
        self.child_action = None
        self.collection_interval = None
        self.id = None
        self.reporting_interval = None
        self.status = None

        ManagedObject.__init__(self, "StatsCollectionPolicy", parent_mo_or_dn, **kwargs)




"""This module contains the general information for MemoryQual ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class MemoryQualConsts():
    CLOCK_UNSPECIFIED = "unspecified"
    LATENCY_UNSPECIFIED = "unspecified"
    MAX_CAP_UNSPECIFIED = "unspecified"
    MIN_CAP_UNSPECIFIED = "unspecified"
    SPEED_UNSPECIFIED = "unspecified"
    UNITS_UNSPECIFIED = "unspecified"
    WIDTH_UNSPECIFIED = "unspecified"


class MemoryQual(ManagedObject):
    """This is MemoryQual class."""

    consts = MemoryQualConsts()
    naming_props = set([])

    mo_meta = MoMeta("MemoryQual", "memoryQual", "memory", VersionMeta.Version111a, "InputOutput", 0x7ff, [], ["admin", "pn-policy", "read-only"], [u'computeQual'], [], ["Add", "Get", "Remove", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "clock": MoPropertyMeta("clock", "clock", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x2, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "latency": MoPropertyMeta("latency", "latency", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "max_cap": MoPropertyMeta("max_cap", "maxCap", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x10, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "min_cap": MoPropertyMeta("min_cap", "minCap", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x40, 0, 256, None, [], []), 
        "speed": MoPropertyMeta("speed", "speed", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x80, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x100, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "units": MoPropertyMeta("units", "units", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x200, None, None, None, ["unspecified"], ["0-4294967295"]), 
        "width": MoPropertyMeta("width", "width", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x400, None, None, None, ["unspecified"], ["0-4294967295"]), 
    }

    prop_map = {
        "childAction": "child_action", 
        "clock": "clock", 
        "dn": "dn", 
        "latency": "latency", 
        "maxCap": "max_cap", 
        "minCap": "min_cap", 
        "rn": "rn", 
        "speed": "speed", 
        "status": "status", 
        "units": "units", 
        "width": "width", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.clock = None
        self.latency = None
        self.max_cap = None
        self.min_cap = None
        self.speed = None
        self.status = None
        self.units = None
        self.width = None

        ManagedObject.__init__(self, "MemoryQual", parent_mo_or_dn, **kwargs)




"""This module contains the general information for GlPolicyNameRuleEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class GlPolicyNameRuleEpConsts():
    TYPE_NO_AUTO = "no-auto"
    TYPE_RENAME_AFTER_EVALUATE = "rename-after-evaluate"
    TYPE_RENAME_BEFORE_EVALUATE = "rename-before-evaluate"


class GlPolicyNameRuleEp(ManagedObject):
    """This is GlPolicyNameRuleEp class."""

    consts = GlPolicyNameRuleEpConsts()
    naming_props = set([])

    mo_meta = MoMeta("GlPolicyNameRuleEp", "glPolicyNameRuleEp", "policyep", VersionMeta.Version201b, "InputOutput", 0x3f, [], ["admin"], [u'glConflictResolutionRuleEp'], [u'glAppendRule'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version201b, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "max_rule_apply_times": MoPropertyMeta("max_rule_apply_times", "maxRuleApplyTimes", "uint", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x4, None, None, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version201b, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "type": MoPropertyMeta("type", "type", "string", VersionMeta.Version201b, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["no-auto", "rename-after-evaluate", "rename-before-evaluate"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "maxRuleApplyTimes": "max_rule_apply_times", 
        "rn": "rn", 
        "status": "status", 
        "type": "type", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.max_rule_apply_times = None
        self.status = None
        self.type = None

        ManagedObject.__init__(self, "GlPolicyNameRuleEp", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ComputePCIeFatalProtocolStats ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputePCIeFatalProtocolStatsConsts():
    SUSPECT_FALSE = "false"
    SUSPECT_NO = "no"
    SUSPECT_TRUE = "true"
    SUSPECT_YES = "yes"


class ComputePCIeFatalProtocolStats(ManagedObject):
    """This is ComputePCIeFatalProtocolStats class."""

    consts = ComputePCIeFatalProtocolStatsConsts()
    naming_props = set([])

    mo_meta = MoMeta("ComputePCIeFatalProtocolStats", "computePCIeFatalProtocolStats", "pciefat-protocol-stats", VersionMeta.Version111a, "OutputOnly", 0xf, [], ["admin", "operations", "read-only"], [u'computeBoard'], [u'computePCIeFatalProtocolStatsHist'], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version111a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dllp_errors": MoPropertyMeta("dllp_errors", "dllpErrors", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dllp_errors_avg": MoPropertyMeta("dllp_errors_avg", "dllpErrorsAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dllp_errors_max": MoPropertyMeta("dllp_errors_max", "dllpErrorsMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dllp_errors_min": MoPropertyMeta("dllp_errors_min", "dllpErrorsMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dllp_errors_running": MoPropertyMeta("dllp_errors_running", "dllpErrorsRunning", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "flow_control_errors": MoPropertyMeta("flow_control_errors", "flowControlErrors", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "flow_control_errors_avg": MoPropertyMeta("flow_control_errors_avg", "flowControlErrorsAvg", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "flow_control_errors_max": MoPropertyMeta("flow_control_errors_max", "flowControlErrorsMax", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "flow_control_errors_min": MoPropertyMeta("flow_control_errors_min", "flowControlErrorsMin", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "flow_control_errors_running": MoPropertyMeta("flow_control_errors_running", "flowControlErrorsRunning", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "intervals": MoPropertyMeta("intervals", "intervals", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "normalized_time_col": MoPropertyMeta("normalized_time_col", "normalizedTimeCol", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "stats_reported": MoPropertyMeta("stats_reported", "statsReported", "int", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version111a, MoPropertyMeta.READ_WRITE, 0x8, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "suspect": MoPropertyMeta("suspect", "suspect", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "thresholded": MoPropertyMeta("thresholded", "thresholded", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "time_collected": MoPropertyMeta("time_collected", "timeCollected", "string", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "update": MoPropertyMeta("update", "update", "uint", VersionMeta.Version111a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dllpErrors": "dllp_errors", 
        "dllpErrorsAvg": "dllp_errors_avg", 
        "dllpErrorsMax": "dllp_errors_max", 
        "dllpErrorsMin": "dllp_errors_min", 
        "dllpErrorsRunning": "dllp_errors_running", 
        "dn": "dn", 
        "flowControlErrors": "flow_control_errors", 
        "flowControlErrorsAvg": "flow_control_errors_avg", 
        "flowControlErrorsMax": "flow_control_errors_max", 
        "flowControlErrorsMin": "flow_control_errors_min", 
        "flowControlErrorsRunning": "flow_control_errors_running", 
        "intervals": "intervals", 
        "normalizedTimeCol": "normalized_time_col", 
        "rn": "rn", 
        "statsReported": "stats_reported", 
        "status": "status", 
        "suspect": "suspect", 
        "thresholded": "thresholded", 
        "timeCollected": "time_collected", 
        "update": "update", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.dllp_errors = None
        self.dllp_errors_avg = None
        self.dllp_errors_max = None
        self.dllp_errors_min = None
        self.dllp_errors_running = None
        self.flow_control_errors = None
        self.flow_control_errors_avg = None
        self.flow_control_errors_max = None
        self.flow_control_errors_min = None
        self.flow_control_errors_running = None
        self.intervals = None
        self.normalized_time_col = None
        self.stats_reported = None
        self.status = None
        self.suspect = None
        self.thresholded = None
        self.time_collected = None
        self.update = None

        ManagedObject.__init__(self, "ComputePCIeFatalProtocolStats", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from nose.tools import *
from ucscsdk.ucsccoreutils import get_meta_info
from ..connection.info import custom_setup, custom_teardown

handle = None


def setup():
    global handle
    handle = custom_setup()


def teardown():
    custom_teardown(handle)


@with_setup(setup, teardown)
def test_001_get_meta():
    meta = get_meta_info(class_id="OrGoRg")
    xml_attribute = meta.xml_attribute
    assert_equal(xml_attribute, "orgOrg")

    meta = get_meta_info(class_id="unknown")
    assert_equal(meta, None)

    meta = get_meta_info(class_id="OrGoRg")
    properties = len(meta.props)
    assert_not_equal(properties, 0)

    meta = get_meta_info(class_id="OrGoRg")
    xml_attribute = meta.props['name'].xml_attribute
    assert_equal(xml_attribute, 'name')

    meta = get_meta_info(class_id="OrGoRg", include_prop=False)
    properties = len(meta.props)
    assert_equal(properties, 0)



"""This module contains the general information for PolicyCommunicationOp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class PolicyCommunicationOpConsts():
    SOURCE_LOCAL = "local"
    SOURCE_PENDING_POLICY = "pending-policy"
    SOURCE_POLICY = "policy"
    SOURCE_UNSPECIFIED = "unspecified"
    TRIGGER_STATUS_TRIGGER_ACKED = "trigger-acked"
    TRIGGER_STATUS_TRIGGER_FAILED = "trigger-failed"
    TRIGGER_STATUS_TRIGGERED = "triggered"
    TRIGGER_STATUS_UNKNOWN = "unknown"


class PolicyCommunicationOp(ManagedObject):
    """This is PolicyCommunicationOp class."""

    consts = PolicyCommunicationOpConsts()
    naming_props = set([])

    mo_meta = MoMeta("PolicyCommunicationOp", "policyCommunicationOp", "comm-ctrl", VersionMeta.Version151a, "InputOutput", 0x3f, [], ["aaa", "admin"], [u'policyControlEpOp'], [u'faultInst'], ["Get", "Set"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "last_modified": MoPropertyMeta("last_modified", "lastModified", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""([0-9]){4}-([0-9]){2}-([0-9]){2}T([0-9]){2}:([0-9]){2}:([0-9]){2}((\.([0-9]){3})){0,1}""", [], []), 
        "remote_error_code": MoPropertyMeta("remote_error_code", "remoteErrorCode", "uint", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, [], []), 
        "remote_error_descr": MoPropertyMeta("remote_error_descr", "remoteErrorDescr", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "source": MoPropertyMeta("source", "source", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x8, None, None, None, ["local", "pending-policy", "policy", "unspecified"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "trigger_status": MoPropertyMeta("trigger_status", "triggerStatus", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x20, None, None, None, ["trigger-acked", "trigger-failed", "triggered", "unknown"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "lastModified": "last_modified", 
        "remoteErrorCode": "remote_error_code", 
        "remoteErrorDescr": "remote_error_descr", 
        "rn": "rn", 
        "source": "source", 
        "status": "status", 
        "triggerStatus": "trigger_status", 
    }

    def __init__(self, parent_mo_or_dn, **kwargs):
        self._dirty_mask = 0
        self.child_action = None
        self.last_modified = None
        self.remote_error_code = None
        self.remote_error_descr = None
        self.source = None
        self.status = None
        self.trigger_status = None

        ManagedObject.__init__(self, "PolicyCommunicationOp", parent_mo_or_dn, **kwargs)




"""This module contains the general information for StorageDiskEp ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class StorageDiskEpConsts():
    DEPLOY_ACTION_ABORT_REPLICATION = "abort-replication"
    DEPLOY_ACTION_CREATE = "create"
    DEPLOY_ACTION_DELETE = "delete"
    DEPLOY_ACTION_MODIFY = "modify"
    DEPLOY_ACTION_NO_ACTION = "no-action"
    DEPLOY_ACTION_REPLACE = "replace"
    DEPLOY_ACTION_RESTORE = "restore"
    DEPLOY_ACTION_SET_OFFLINE = "set-offline"
    DEPLOY_ACTION_SET_ONLINE = "set-online"
    MEMBERSHIP_DOWN = "down"
    MEMBERSHIP_HOT_STANDBY = "hot-standby"
    MEMBERSHIP_UNKNOWN = "unknown"
    MEMBERSHIP_UP = "up"
    OPER_STATE_COMPUTE_DEGRADED = "compute-degraded"
    OPER_STATE_COMPUTE_INOPERABLE = "compute-inoperable"
    OPER_STATE_OFFLINE = "offline"
    OPER_STATE_ONLINE = "online"
    OPER_STATE_UNDEFINED = "undefined"


class StorageDiskEp(ManagedObject):
    """This is StorageDiskEp class."""

    consts = StorageDiskEpConsts()
    naming_props = set([u'id'])

    mo_meta = MoMeta("StorageDiskEp", "storageDiskEp", "disk-[id]", VersionMeta.Version131a, "InputOutput", 0x1f, [], ["read-only"], [u'storageDiskGroup'], [], ["Get"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "deploy_action": MoPropertyMeta("deploy_action", "deployAction", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["abort-replication", "create", "delete", "modify", "no-action", "replace", "restore", "set-offline", "set-online"], []), 
        "disk_dn": MoPropertyMeta("disk_dn", "diskDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "ep_dn": MoPropertyMeta("ep_dn", "epDn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], []), 
        "membership": MoPropertyMeta("membership", "membership", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["down", "hot-standby", "unknown", "up"], []), 
        "oper_state": MoPropertyMeta("oper_state", "operState", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["compute-degraded", "compute-inoperable", "offline", "online", "undefined"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "deployAction": "deploy_action", 
        "diskDn": "disk_dn", 
        "dn": "dn", 
        "epDn": "ep_dn", 
        "id": "id", 
        "membership": "membership", 
        "operState": "oper_state", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.deploy_action = None
        self.disk_dn = None
        self.ep_dn = None
        self.membership = None
        self.oper_state = None
        self.status = None

        ManagedObject.__init__(self, "StorageDiskEp", parent_mo_or_dn, **kwargs)




"""This module contains the general information for ExtpolVersionHolder ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ExtpolVersionHolderConsts():
    CONN_PROTOCOL_IPV4 = "ipv4"
    CONN_PROTOCOL_IPV6 = "ipv6"
    CONN_PROTOCOL_UNKNOWN = "unknown"
    OPERATION_ADD = "add"
    OPERATION_DELETE = "delete"
    OPERATION_NO_OPERATION = "noOperation"
    PRODUCT_FAMILY_UCS_CLASSIC = "ucs-classic"
    PRODUCT_FAMILY_UCS_CLASSIC_3GEN = "ucs-classic-3gen"
    PRODUCT_FAMILY_UCS_CLASSIC_4GEN = "ucs-classic-4gen"
    PRODUCT_FAMILY_UCS_MINI = "ucs-mini"
    VERSION_HOLDER_FALSE = "false"
    VERSION_HOLDER_NO = "no"
    VERSION_HOLDER_TRUE = "true"
    VERSION_HOLDER_YES = "yes"
    VERSION_HOLDER_FLAG_FALSE = "false"
    VERSION_HOLDER_FLAG_NO = "no"
    VERSION_HOLDER_FLAG_TRUE = "true"
    VERSION_HOLDER_FLAG_YES = "yes"


class ExtpolVersionHolder(ManagedObject):
    """This is ExtpolVersionHolder class."""

    consts = ExtpolVersionHolderConsts()
    naming_props = set([u'id'])

    mo_meta = MoMeta("ExtpolVersionHolder", "extpolVersionHolder", "versionHolder-[id]", VersionMeta.Version131a, "InputOutput", 0x1f, [], ["read-only"], [], [], [None])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version131a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "conn_protocol": MoPropertyMeta("conn_protocol", "connProtocol", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ipv4", "ipv6", "unknown"], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "guid": MoPropertyMeta("guid", "guid", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "host": MoPropertyMeta("host", "host", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, r"""^[A-Za-z]([A-Za-z0-9-]*[A-Za-z0-9])?$|^[A-Za-z0-9]([A-Za-z0-9-]*[A-Za-z0-9])?(\.[A-Za-z0-9]([A-Za-z0-9-]*[A-Za-z0-9])?)*(\.[A-Za-z]([A-Za-z0-9-]*[A-Za-z0-9])?)$|^([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([0-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])\.([1-9]|[1-9][0-9]|1[0-9][0-9]|2[0-4][0-9]|25[0-5])$""", [], []), 
        "id": MoPropertyMeta("id", "id", "uint", VersionMeta.Version131a, MoPropertyMeta.NAMING, 0x4, None, None, None, [], []), 
        "ipv4": MoPropertyMeta("ipv4", "ipv4", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []), 
        "ipv6": MoPropertyMeta("ipv6", "ipv6", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "operation": MoPropertyMeta("operation", "operation", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["add", "delete", "noOperation"], []), 
        "product_family": MoPropertyMeta("product_family", "productFamily", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["ucs-classic", "ucs-classic-3gen", "ucs-classic-4gen", "ucs-mini"], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version131a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "version_holder": MoPropertyMeta("version_holder", "versionHolder", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
        "version_holder_flag": MoPropertyMeta("version_holder_flag", "versionHolderFlag", "string", VersionMeta.Version131a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["false", "no", "true", "yes"], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "connProtocol": "conn_protocol", 
        "dn": "dn", 
        "guid": "guid", 
        "host": "host", 
        "id": "id", 
        "ipv4": "ipv4", 
        "ipv6": "ipv6", 
        "operation": "operation", 
        "productFamily": "product_family", 
        "rn": "rn", 
        "status": "status", 
        "versionHolder": "version_holder", 
        "versionHolderFlag": "version_holder_flag", 
    }

    def __init__(self, parent_mo_or_dn, id, **kwargs):
        self._dirty_mask = 0
        self.id = id
        self.child_action = None
        self.conn_protocol = None
        self.guid = None
        self.host = None
        self.ipv4 = None
        self.ipv6 = None
        self.operation = None
        self.product_family = None
        self.status = None
        self.version_holder = None
        self.version_holder_flag = None

        ManagedObject.__init__(self, "ExtpolVersionHolder", parent_mo_or_dn, **kwargs)




# Copyright 2015 Cisco Systems, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License prop
#  http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
This module contains the ManagedObject and GenericManagedObject Class.
"""

from __future__ import print_function

import logging
import os

from . import ucscgenutils
from . import ucsccoreutils
from . import ucsccoremeta

try:
    import xml.etree.cElementTree as ET
    from xml.etree.cElementTree import Element, SubElement
except ImportError:
    import cElementTree as ET
    from cElementTree import Element, SubElement

from .ucsccoremeta import WriteXmlOption
from .ucscexception import UcscValidationException, UcscWarning
from .ucsccore import UcscBase

log = logging.getLogger('ucscentral')


class _GenericProp():
    """
    Internal class to handle the unknown property.
    """
    def __init__(self, name, value, is_dirty):
        self.name = name
        self.value = value
        self.is_dirty = is_dirty


class ManagedObject(UcscBase):
    """
    This class structures/represents all the managed objects.
    """

    DUMMY_DIRTY = "0x1L"
    __internal_prop = frozenset(
        ["_dirty_mask", "_class_id", "_child", "_handle", ''])

    def __init__(
            self,
            class_id,
            parent_mo_or_dn=None,
            from_xml_response=False,
            **kwargs):
        self.__parent_mo = None
        self.__status = None
        self.__parent_dn = None
        self.__xtra_props = {}
        self.__xtra_props_dirty_mask = 0x1

        if parent_mo_or_dn:
            if isinstance(parent_mo_or_dn, ManagedObject):
                self.__parent_mo = parent_mo_or_dn
                self.__parent_dn = self.__parent_mo.dn
            elif isinstance(parent_mo_or_dn, str):
                self.__parent_dn = parent_mo_or_dn
            else:
                raise ValueError('parent mo or dn must be specified')

        if not from_xml_response:
            self._rn_set()
            self._dn_set()

        xml_attribute = self.mo_meta.xml_attribute

        UcscBase.__init__(self, ucscgenutils.word_u(xml_attribute))

        if self.__parent_mo:
            self.__parent_mo.child_add(self)

        if kwargs:
            for prop_name, prop_value in ucscgenutils.iteritems(kwargs):
                if prop_name not in self.prop_meta:
                    log.debug("Unknown property %s" % prop_name)
                self.__set_prop(prop_name, prop_value)

    @property
    def parent_mo(self):
        """Getter method of ManagedObject Class"""

        return self.__parent_mo

    def _rn_set(self):
        """
        Internal method to set rn
        """

        if "prop_meta" in dir(self) and "rn" in self.prop_meta:
            self.rn = self.make_rn()
        else:
            self.rn = ""

    def _dn_set(self):
        """
        Internal method to set dn
        """

        if "prop_meta" in dir(self) and "dn" in self.prop_meta:
            if self.__parent_dn:
                self.dn = self.__parent_dn + '/' + self.rn
            else:
                self.dn = self.rn
        else:
            self.dn = ""

    def __setattr__(self, name, value):
        """
        overridden setattr method
        """

        if "prop_meta" in dir(self) and name in self.prop_meta:
            if name in dir(self):
                self.__set_prop(name, value)
            else:
                if value:
                    if not self.prop_meta[name].validate_property_value(value):
                        raise ValueError("Invalid Value Exception - "
                                         "[%s]: Prop <%s>, Value<%s>. "
                                         % (self.__class__.__name__,
                                            name,
                                            value))
                object.__setattr__(self, name, value)
                if self.prop_meta[name].mask is not None:
                    self._dirty_mask |= self.prop_meta[name].mask
        elif name.startswith("_"):
            object.__setattr__(self, name, value)
        else:
            # These are properties which the current version of ucscsdk
            # does not know of.
            # The code will come here lot often, when using older version of
            # ucscsdk with newer releases on the UcsCentral.
            # This needs to be handled so that the same sdk can work across
            # multiple ucs central releases
            self.__xtra_props[name] = _GenericProp(name, value, True)
            self._dirty_mask |= self.__xtra_props_dirty_mask
            object.__setattr__(self, name, value)

    def __set_prop(self, name, value, mark_dirty=True, forced=False):
        """
        Internal method to set the properties after validation

        Args:
            name (str): property name
            value (str): property value
            mark_dirty (bool): if True, property will be part of xml request
            forced (bool): if True, set the value without validation

        Returns:
            None
        """

        if not forced:
            prop_meta = self.prop_meta[name]
            if prop_meta.access != ucsccoremeta.MoPropertyMeta.READ_WRITE:
                if getattr(self, name) is not None or \
                        prop_meta.access != \
                        ucsccoremeta.MoPropertyMeta.CREATE_ONLY:
                    raise ValueError("%s is not a read-write property." % name)
            if value and not prop_meta.validate_property_value(value):
                raise ValueError("Invalid Value Exception - "
                                 "[%s]: Prop <%s>, Value<%s>. "
                                 % (self.__class__.__name__,
                                    name,
                                    value))
                # return False
            if prop_meta.mask and mark_dirty:
                self._dirty_mask |= prop_meta.mask
        object.__setattr__(self, name, value)

    def __get_prop(self, name):
        return object.__getattribute__(self, name)

    def check_prop_match(self, **kwargs):
        for prop_name in kwargs:
            if prop_name not in self.prop_meta.keys():
                raise ValueError("Invalid Property Name Exception - "
                                 "Class [%s]: Prop <%s> "
                                 % (self.__class__.__name__, prop_name))

            if kwargs[prop_name] is not None and \
                    kwargs[prop_name] != self.__get_prop(prop_name):
                return False
        return True

    def set_prop_multiple(self, **kwargs):
        for prop_name in kwargs:
            if prop_name not in self.prop_meta.keys():
                UcscWarning("Invalid Property Name for "
                            "Class [%s]: Prop <%s>, setting it forcefully"
                            % (self.__class__.__name__, prop_name))
                self.__set_prop(prop_name, kwargs[prop_name], forced=True)
            else:
                self.__set_prop(prop_name, kwargs[prop_name])

    def __str__(self):
        """
        Method to return string representation of a managed object.
        """

        ts = 8
        out_str = "\n"
        out_str += "Managed Object\t\t\t:\t" + str(self._class_id) + "\n"
        out_str += "-" * len("Managed Object") + "\n"
        for prop, prop_value in sorted(ucscgenutils.iteritems(
                self.__dict__)):
            if prop in ManagedObject.__internal_prop or prop.startswith(
                    "_ManagedObject__"):
                continue
            if prop in self.__xtra_props:
                prop = "[X]" + str(prop)
            out_str += str(prop).ljust(ts * 4) + ':' + str(
                prop_value) + "\n"

        out_str += "\n"
        return out_str

    def mark_dirty(self):
        """
        This method marks the managed object dirty.
        """

        if self.__class__.__name__ == "ManagedObject" and not self.is_dirty():
            self._dirty_mask = ManagedObject.DUMMY_DIRTY
        elif "mo_meta" in dir(self):
            self._dirty_mask = self.mo_meta.mask

    def is_dirty(self):
        """
        This method checks if managed object is dirty.
        """

        return self._dirty_mask != 0 or self.child_is_dirty()

    # Ideally an rn should never change across ucs central releases.
    # but we do have some of these cases
    # These cause an issue, because we cannot parse them
    # the below is a special case to handle these cases
    def rn_is_special_case(self):
        """
        Method to handle if rn pattern is different across UcsCentral Version
        """

        if self.__class__.__name__ == "StorageLocalDiskPartition":
            return True
        return False

    def rn_get_special_case(self):
        """
        Method to handle if rn pattern is different across UcsCentral Version
        """

        if self.__class__.__name__ == "StorageLocalDiskPartition":
            # some version of ucs central have rn "partition" instead of
            # "partition-id"
            return "partition"

    def make_rn(self):
        """
        This method returns the Rn for a managed object.
        """

        import re

        rn_pattern = self.mo_meta.rn
        for prop in re.findall(r"""\[([^\]]*)\]""", rn_pattern):
            if prop in self.prop_meta:
                if getattr(self, prop):
                    rn_pattern = re.sub(r"""\[%s\]""" % prop,
                                        '%s' % getattr(self, prop), rn_pattern)
                else:
                    log.debug('Property "%s" was None in make_rn' % prop)
                    if self.rn_is_special_case():
                        return self.rn_get_special_case()
                    raise UcscValidationException(
                        'Property "%s" was None in make_rn' % prop)
            else:
                log.debug(
                    'Property "%s" was not found in make_rn arguments' % prop)
                if self.rn_is_special_case():
                    return self.rn_get_special_case()
                raise UcscValidationException(
                    'Property "%s" was not found in make_rn arguments' % prop)

        return rn_pattern

    def to_xml(self, xml_doc=None, option=None, elem_name=None):
        """
        Method writes the xml representation of the managed object.
        """

        if option == WriteXmlOption.DIRTY and not self.is_dirty():
            log.debug("Object is not dirty")
            return

        xml_obj = self.elem_create(class_tag=self.mo_meta.xml_attribute,
                                   xml_doc=xml_doc,
                                   override_tag=elem_name)

        for key in self.__dict__:
            if key != 'rn' and key in self.prop_meta:
                mo_prop_meta = self.prop_meta[key]
                if (option != WriteXmlOption.DIRTY or (
                    mo_prop_meta.mask is not None and
                        self._dirty_mask & mo_prop_meta.mask != 0)):
                    value = getattr(self, key)
                    if value is not None:
                        xml_obj.set(mo_prop_meta.xml_attribute, value)
            else:
                if key not in self.__xtra_props:
                    # This is an internal property
                    # This should not be a part of the xml
                    continue

                # This is an unknown property
                # This should be a part of the xml
                # The server might understand this property, even though
                # the sdk does not
                if option != WriteXmlOption.DIRTY or \
                        self.__xtra_props[key].is_dirty:
                    value = self.__xtra_props[key].value
                    if value is not None:
                        xml_obj.set(key, value)

        if 'dn' not in xml_obj.attrib:
            xml_obj.set('dn', self.dn)

        self.child_to_xml(xml_obj, option)
        return xml_obj

    def from_xml(self, elem, handle=None):
        """
        Method updates the object from the xml representation of the managed
        object.
        """

        self._handle = handle
        if elem.attrib:
            if self.__class__.__name__ != "ManagedObject":
                for attr_name, attr_value in ucscgenutils.iteritems(
                        elem.attrib):
                    if attr_name in self.prop_map:
                        attr_name = self.prop_map[attr_name]
                    else:
                        self.__xtra_props[attr_name] = _GenericProp(
                            attr_name,
                            attr_value,
                            False)
                    object.__setattr__(self, attr_name, attr_value)
            else:
                for attr_name, attr_value in ucscgenutils.iteritems(
                        elem.attrib):
                    object.__setattr__(self, attr_name, attr_value)

        if hasattr(self, 'rn') and not hasattr(self, 'dn'):
            self._dn_set()
        elif not hasattr(self, 'rn') and hasattr(self, 'dn'):
            self.__set_prop("rn", os.path.basename(self.dn), forced=True)
        self.mark_clean()

        child_elems = list(elem)
        if child_elems:
            for child_elem in child_elems:
                if not ET.iselement(child_elem):
                    continue

                if self.__class__.__name__ != "ManagedObject" and (
                        child_elem.tag in self.mo_meta.field_names):
                    pass

                class_id = ucscgenutils.word_u(child_elem.tag)
                child_obj = ucsccoreutils.get_ucsc_obj(class_id,
                                                       child_elem,
                                                       self)
                self.child_add(child_obj)
                child_obj.from_xml(child_elem, handle)

    def sync_mo(self, mo):
        """
        Method to return string representation of a managed object.
        """

        for prop, prop_value in sorted(ucscgenutils.iteritems(
                self.__dict__)):
            if prop in ManagedObject.__internal_prop or prop.startswith(
                    "_ManagedObject__"):
                continue
            mo.__dict__[prop] = prop_value
        return None

    def show_tree(self, level=0):
        """
        Method to return string representation of a managed object.
        """

        indent = "  "
        level_indent = "%s%s)" % (indent * level, level)
        # level_key_dn = "level_%s_dn" % (str(level))
        print("%s %s[%s]" % (level_indent, self._class_id, self.dn))
        for ch_ in self.children:
            level += 1
            ch_.show_tree(level)
            level -= 1
        return None

    def show_hierarchy(self, level=0, depth=None, show_level=[]):
        """
        Method to return string representation of a managed object.
        """

        from .ucsccoreutils import print_mo_hierarchy

        print_mo_hierarchy(self._class_id, level, depth,
                           show_level)


def generic_mo_from_xml(xml_str):
    """
    create GenericMo object from xml string
    """
    root_elem = ET.fromstring(xml_str)
    class_id = root_elem.tag
    gmo = GenericMo(class_id)
    gmo.from_xml(root_elem)
    return gmo


def generic_mo_from_xml_elem(elem):
    """
    create GenericMo object from xml element
    """

    from . import ucscxmlcodec as xc
    xml_str = xc.to_xml_str(elem)
    gmo = generic_mo_from_xml(xml_str)
    return gmo


class GenericMo(UcscBase):
    """
    This class implements a Generic Managed Object.

    Args:
        class_id (str): class id of managed object
        parent_mo_or_dn (ManagedObject or str): parent managed object or dn
    """

    # Every variable that should not be a part of the final xml
    # should start with a underscore in this class
    def __init__(self, class_id, parent_mo_or_dn=None, **kwargs):

        self.__properties = {}

        if isinstance(parent_mo_or_dn, GenericMo):
            self.__parent_mo = parent_mo_or_dn
            self.__parent_dn = parent_mo_or_dn.dn
        elif isinstance(parent_mo_or_dn, str):
            # if (parent_mo_or_dn == "") and ("dn" in kwargs):
            #     parent_mo_or_dn = kwargs["dn"]
            self.__parent_dn = parent_mo_or_dn
            self.__parent_mo = None
        elif parent_mo_or_dn is None:
            self.__parent_dn = ""
            self.__parent_mo = None
        else:
            raise ValueError("parent_mo_or_dn should be an instance of str or "
                             "GenericMo")

        UcscBase.__init__(self, class_id)

        if kwargs:
            for key, value in ucscgenutils.iteritems(kwargs):
                self.__dict__[key] = str(value)
                self.__properties[key] = str(value)

        if 'rn' in dir(self) and 'dn' in dir(self):
            pass
        elif 'rn' in dir(self) and 'dn' not in dir(self):
            if self.__parent_dn is not None and self.__parent_dn != "":
                self.dn = self.__parent_dn + '/' + self.rn
                self.__properties['dn'] = self.dn
            else:
                self.dn = self.rn
                self.__properties['dn'] = self.dn
        elif 'rn' not in dir(self) and 'dn' in dir(self):
            self.rn = os.path.basename(self.dn)
            self.__properties['rn'] = self.rn
        else:
            self.rn = ""
            self.dn = ""

        if self.__parent_mo:
            self.__parent_mo.child_add(self)

    def to_xml(self, xml_doc=None, option=None):
        """
        This method returns the xml element node for the current object
        with it's hierarchy.

        Args:
            xml_doc: document to which the Mo attributes are added.
                    Can be None.
            option: not required for Generic Mo class object

        Example:
            from ucscsdk.ucscmo import GenericMo\n
            args = {"a": 1, "b": 2, "c":3}\n
            obj = GenericMo("testLsA", "org-root", **args)\n
            obj1 = GenericMo("testLsB", "org-root", **args)\n
            obj.add_child(obj1)\n
            elem = obj.write_xml()\n

            import ucscsdk.ucscxmlcodec as xc\n
            xc.to_xml_str(elem)\n

        Output:
            '<testLsA a="1" b="2" c="3" dn="org-root/" rn="">\n
                <testLsB a="1" b="2" c="3" dn="org-root/" rn="" />\n
            </testLsA>'
        """

        if xml_doc is None:
            xml_obj = Element(ucscgenutils.word_l(self._class_id))
        else:
            xml_obj = SubElement(xml_doc, ucscgenutils.word_l(
                self._class_id))
        for key in self.__dict__:
            if not key.startswith('_'):
                xml_obj.set(key, getattr(self, key))
        self.child_to_xml(xml_obj)
        return xml_obj

    @property
    def properties(self):
        """Getter Method of GenericMO Class"""
        return self.__properties

    def from_xml(self, elem, handle=None):
        """
        This method is form objects out of xml element.
        This is called internally from ucscxmlcode.from_xml_str
        method.

        Example:
            xml = '<testLsA a="1" b="2" c="3" dn="org-root/" rn="">
            <testLsB a="1" b="2" c="3" dn="org-root/" rn="" /></testLsA>'\n
            obj = xc.from_xml_str(xml)\n

            print type(obj)\n

        Outputs:
            <class 'ucscsdk.ucscmo.GenericMo'>
        """

        if elem is None:
            return None

        self._handle = handle
        self._class_id = elem.tag
        if elem.attrib:
            for name, value in ucscgenutils.iteritems(elem.attrib):
                self.__dict__[name] = value
                self.__properties[name] = str(value)

        if self.rn and self.dn:
            pass
        elif self.rn and not self.dn:
            if self.__parent_dn is not None and self.__parent_dn != "":
                self.dn = self.__parent_dn + '/' + self.rn
                self.__properties['dn'] = self.dn
            else:
                self.dn = self.rn
                self.__properties['dn'] = self.dn
        elif not self.rn and self.dn:
            self.rn = os.path.basename(self.dn)
            self.__properties['rn'] = self.rn
        # else:
        #     raise ValueError("Both rn and dn does not present.")

        children = list(elem)
        if children:
            for child in children:
                if not ET.iselement(child):
                    continue
                class_id = ucscgenutils.word_u(child.tag)
                pdn = None
                if 'dn' in dir(self):
                    pdn = self.dn
                child_obj = GenericMo(class_id, parent_mo_or_dn=pdn)
                self.child_add(child_obj)
                child_obj.from_xml(child, handle)

    def __get_mo_obj(self, class_id):
        """
        Internal methods to create managed object from class_id
        """

        import inspect

        mo_class = ucsccoreutils.load_class(class_id)
        mo_class_params = inspect.getargspec(mo_class.__init__)[0][2:]
        mo_class_param_dict = {}
        for param in mo_class_params:
            mo_param = mo_class.prop_meta[param].xml_attribute
            if mo_param not in self.__properties:
                if 'rn' in self.__properties:
                    rn_str = self.__properties['rn']
                elif 'dn' in self.__properties:
                    rn_str = os.path.basename(self.__properties['dn'])

                rn_pattern = mo_class.mo_meta.rn
                np_dict = ucsccoreutils.get_naming_props(rn_str,
                                                         rn_pattern)
                if param not in np_dict:
                    mo_class_param_dict[param] = ""
                else:
                    mo_class_param_dict[param] = np_dict[param]
            else:
                mo_class_param_dict[param] = self.__properties[mo_param]

        p_dn = ""

        if 'topRoot' in mo_class.mo_meta.parents:
            mo_obj = mo_class(**mo_class_param_dict)
        else:
            mo_obj = mo_class(parent_mo_or_dn=p_dn, **mo_class_param_dict)
        return mo_obj

    def to_mo(self):
        """
        Converts GenericMo to ManagedObject
        """

        from . import ucscmeta

        class_id = ucscgenutils.word_u(self._class_id)
        if class_id not in ucscmeta.MO_CLASS_ID:
            return None

        mo = self.__get_mo_obj(class_id)
        if not mo:  # or not isinstance(mo, ManagedObject):
            return None

        for prop in self.__properties:
            if prop in mo.prop_map:
                mo.__dict__[mo.prop_map[prop]] = self.__properties[prop]
            else:
                UcscWarning("Property %s Not Exist in MO %s" % (
                    ucscgenutils.word_u(prop), class_id))

        if len(self.child):
            for ch_ in self.child:
                mo_ch = ch_.to_mo()
                mo.child_add(mo_ch)

        return mo

    def __str__(self):
        ts = 8
        if isinstance(self, GenericMo):
            out_str = "\n"
            out_str += 'GenericMo'.ljust(ts * 4) + ':' + str(
                self._class_id) + "\n"
            out_str += "-" * len("GenericMo") + "\n"
            for prop, prop_val in sorted(ucscgenutils.iteritems(
                    self.__dict__)):
                if prop.startswith('_'):
                    continue
                out_str += str(prop).ljust(ts * 4) + ':' + str(prop_val) + "\n"

            return out_str



"""This module contains the general information for ComputeSystemAddrQual ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class ComputeSystemAddrQualConsts():
    pass


class ComputeSystemAddrQual(ManagedObject):
    """This is ComputeSystemAddrQual class."""

    consts = ComputeSystemAddrQualConsts()
    naming_props = set([u'minAddr', u'maxAddr'])

    mo_meta = MoMeta("ComputeSystemAddrQual", "computeSystemAddrQual", "ip-from-[min_addr]-to-[max_addr]", VersionMeta.Version101a, "InputOutput", 0x3f, [], ["admin", "pn-policy", "read-only"], [u'computeDomainQual', u'computeSystemQual'], [], ["Add", "Get", "Remove"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version101a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x2, 0, 256, None, [], []), 
        "max_addr": MoPropertyMeta("max_addr", "maxAddr", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x4, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []), 
        "min_addr": MoPropertyMeta("min_addr", "minAddr", "string", VersionMeta.Version101a, MoPropertyMeta.NAMING, 0x8, 0, 256, r"""((([0-9]){1,3}\.){3}[0-9]{1,3})""", [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version101a, MoPropertyMeta.READ_ONLY, 0x10, 0, 256, None, [], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version101a, MoPropertyMeta.READ_WRITE, 0x20, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "dn": "dn", 
        "maxAddr": "max_addr", 
        "minAddr": "min_addr", 
        "rn": "rn", 
        "status": "status", 
    }

    def __init__(self, parent_mo_or_dn, min_addr, max_addr, **kwargs):
        self._dirty_mask = 0
        self.min_addr = min_addr
        self.max_addr = max_addr
        self.child_action = None
        self.status = None

        ManagedObject.__init__(self, "ComputeSystemAddrQual", parent_mo_or_dn, **kwargs)




"""This module contains the meta information of ConfigPublishVlan ExternalMethod."""

from ..ucsccoremeta import MethodMeta, MethodPropertyMeta

method_meta = MethodMeta("ConfigPublishVlan", "configPublishVlan", "Version142b")

prop_meta = {
    "cookie": MethodPropertyMeta("Cookie", "cookie", "Xs:string", "Version142b", "InputOutput", False),
    "in_domain": MethodPropertyMeta("InDomain", "inDomain", "ReferenceObject", "Version142b", "Input", False),
    "in_vlan_name": MethodPropertyMeta("InVlanName", "inVlanName", "Xs:string", "Version142b", "Input", False),
}

prop_map = {
    "cookie": "cookie",
    "inDomain": "in_domain",
    "inVlanName": "in_vlan_name",
}




"""This module contains the general information for TagInstance ManagedObject."""

from ...ucscmo import ManagedObject
from ...ucsccoremeta import UcscVersion, MoPropertyMeta, MoMeta
from ...ucscmeta import VersionMeta


class TagInstanceConsts():
    SRC_DME_CENTRAL_MGR = "central-mgr"
    SRC_DME_IDENTIFIER_MGR = "identifier-mgr"
    SRC_DME_MGMT_CONTROLLER = "mgmt-controller"
    SRC_DME_OPERATION_MGR = "operation-mgr"
    SRC_DME_POLICY_MGR = "policy-mgr"
    SRC_DME_RESOURCE_MGR = "resource-mgr"
    SRC_DME_SERVER_MGR = "server-mgr"
    SRC_DME_SERVICE_REG = "service-reg"
    SRC_DME_STATS_MGR = "stats-mgr"
    SRC_DME_UNKNOWN = "unknown"


class TagInstance(ManagedObject):
    """This is TagInstance class."""

    consts = TagInstanceConsts()
    naming_props = set([u'defName', u'value', u'taggedObjectDn'])

    mo_meta = MoMeta("TagInstance", "tagInstance", "type-[def_name]-inst-[value]-obj-[tagged_object_dn]", VersionMeta.Version151a, "InputOutput", 0x7f, [], ["aaa", "admin", "ext-lan-config", "ext-lan-policy", "ext-lan-qos", "ext-lan-security", "ext-san-config", "ext-san-policy", "ext-san-qos", "ext-san-security", "fault", "ls-compute", "ls-config", "ls-config-policy", "ls-ext-access", "ls-network", "ls-network-policy", "ls-qos", "ls-qos-policy", "ls-security", "ls-security-policy", "ls-server", "ls-server-oper", "ls-server-policy", "ls-storage", "ls-storage-policy", "operations", "org-management", "pn-equipment", "pn-maintenance", "pn-policy", "pn-security", "pod-config", "pod-policy", "pod-qos", "pod-security", "read-only", "stats-management", "tag"], [u'tagInstanceEp'], [], ["Add", "Get", "Remove"])

    prop_meta = {
        "child_action": MoPropertyMeta("child_action", "childAction", "string", VersionMeta.Version151a, MoPropertyMeta.INTERNAL, None, None, None, r"""((deleteAll|ignore|deleteNonPresent),){0,2}(deleteAll|ignore|deleteNonPresent){0,1}""", [], []), 
        "def_dn": MoPropertyMeta("def_dn", "defDn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 256, None, [], []), 
        "def_name": MoPropertyMeta("def_name", "defName", "string", VersionMeta.Version151a, MoPropertyMeta.NAMING, 0x2, None, None, r"""[ !#$%&\(\)\*\+,\-\.:;=\?@\[\]_\{\|\}~a-zA-Z0-9]{1,32}""", [], []), 
        "dn": MoPropertyMeta("dn", "dn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x4, 0, 256, None, [], []), 
        "object_name": MoPropertyMeta("object_name", "objectName", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, r"""[ !#$%&\(\)\*\+,\-\.:;=\?@\[\]_\{\|\}~a-zA-Z0-9]{0,32}""", [], []), 
        "object_type": MoPropertyMeta("object_type", "objectType", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, 0, 510, None, [], []), 
        "rn": MoPropertyMeta("rn", "rn", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, 0x8, 0, 256, None, [], []), 
        "src_dme": MoPropertyMeta("src_dme", "srcDme", "string", VersionMeta.Version151a, MoPropertyMeta.READ_ONLY, None, None, None, None, ["central-mgr", "identifier-mgr", "mgmt-controller", "operation-mgr", "policy-mgr", "resource-mgr", "server-mgr", "service-reg", "stats-mgr", "unknown"], []), 
        "status": MoPropertyMeta("status", "status", "string", VersionMeta.Version151a, MoPropertyMeta.READ_WRITE, 0x10, None, None, r"""((removed|created|modified|deleted),){0,3}(removed|created|modified|deleted){0,1}""", [], []), 
        "tagged_object_dn": MoPropertyMeta("tagged_object_dn", "taggedObjectDn", "string", VersionMeta.Version151a, MoPropertyMeta.NAMING, 0x20, 0, 256, None, [], []), 
        "value": MoPropertyMeta("value", "value", "string", VersionMeta.Version151a, MoPropertyMeta.NAMING, 0x40, 1, 64, None, [], []), 
    }

    prop_map = {
        "childAction": "child_action", 
        "defDn": "def_dn", 
        "defName": "def_name", 
        "dn": "dn", 
        "objectName": "object_name", 
        "objectType": "object_type", 
        "rn": "rn", 
        "srcDme": "src_dme", 
        "status": "status", 
        "taggedObjectDn": "tagged_object_dn", 
        "value": "value", 
    }

    def __init__(self, parent_mo_or_dn, def_name, value, tagged_object_dn, **kwargs):
        self._dirty_mask = 0
        self.def_name = def_name
        self.value = value
        self.tagged_object_dn = tagged_object_dn
        self.child_action = None
        self.def_dn = None
        self.object_name = None
        self.object_type = None
        self.src_dme = None
        self.status = None

        ManagedObject.__init__(self, "TagInstance", parent_mo_or_dn, **kwargs)

